<?php
/**
 * Application.
 *
 * @package Flat101\Security
 */

namespace Flat101\Security;

use Flat101\Security\Controller\BlocksRunner;
use Flat101\Security\Controller\PagesBuilder;
use Flat101\Security\Controller\PagesChecker;
use Flat101\Security\Util\ActivationUtil;
use Flat101\Security\Util\Debug;

/**
 * Main plugin class for this app.
 */
class App {

	/**
	 * Initialize the plugin.
	 *
	 * @return self
	 */
	public static function init() {
		static $self = null;

		if ( null === $self ) {
			$self = new self();

			Debug::request();

			register_activation_hook( SCRIPT, array( $self, 'activation' ) );
			register_deactivation_hook( SCRIPT, array( $self, 'deactivation' ) );

			add_action( 'plugins_loaded', array( $self, 'plugins_loaded' ) );
			add_action( 'init', array( $self, 'initialization' ) );
		}

		return $self;
	}

	/**
	 * Uninstall the plugin. It must be called from /uninstall.php.
	 */
	public static function uninstall() {
		PagesChecker::uninstall();
	}

	/**
	 * When this plugin is activated.
	 */
	public function activation() {
		ActivationUtil::check_php_version( SCRIPT, PHP_MIN_VERSION );
		ActivationUtil::check_wp_version( SCRIPT, WP_MIN_VERSION );
	}

	/**
	 * When this plugin is deactivated.
	 */
	public function deactivation() {
	}


	/**
	 * Fires once activated plugins have loaded.
	 */
	public function plugins_loaded() {

		// Load plugin translations (.mo).
		load_plugin_textdomain( 'flat101-security', false, dirname( plugin_basename( SCRIPT ) ) . '/languages/' );

		// Check the configuration of pages and blocks.
		( new PagesChecker() )->check();

		// Build the admin pages.
		( new PagesBuilder() )->build();
	}


	/**
	 * Fires after WordPress has finished loading but before any headers are sent.
	 */
	public function initialization() {

		// Execute optimization and security improvements.
		( new BlocksRunner() )->run();
	}
}
