<?php
/**
 * FileEditBlock.
 *
 * @package Flat101\Security\Model\Block
 */

namespace Flat101\Security\Model\Block;

use Carbon_Fields\Field\Field;
use Flat101\Security\Model\Entity\Block;
use Flat101\Security\Model\Entity\Setting;

/**
 * FileEditBlock class.
 */
class FileEditBlock extends Block {

	/**
	 * Block constructor.
	 */
	public function __construct() {
		parent::__construct(
			esc_html__( 'File Edit', 'flat101-security' ),
			'file_edit',
			array(
				new Setting( 'disabled', true, esc_html__( 'Disable File Editing', 'flat101-security' ) ),
			)
		);
	}

	// PHPDoc (inherited).
	// phpcs:ignore Squiz.Commenting.FunctionComment.Missing
	public function get_description() {
		return wp_kses_post(
			__(
				'Disabling file editing is a security measure which prevents users from altering plugin and theme files via
				the WordPress admin interface. This can help mitigate the risk of unauthorized code alterations. For further
				details, refer to the
				<a href="https://developer.wordpress.org/apis/wp-config-php/#disable-the-plugin-and-theme-file-editor"
				target="_blank" rel="noopener noreferrer">WordPress documentation</a>.',
				'flat101-security'
			)
		);
	}

	// PHPDoc (inherited).
	// phpcs:ignore Squiz.Commenting.FunctionComment.Missing
	public function get_fields() {
		return array(

			Field::make( 'checkbox', $this->get_option_name( 'disabled' ), $this->get_setting_label( 'disabled' ) )
			->set_default_value( $this->get_setting_default_value( 'disabled' ) )
			->set_help_text(
				__( 'Enable this option to disable file editing via the WordPress admin interface.', 'flat101-security' )
			),

		);
	}

	// PHPDoc (inherited).
	// phpcs:ignore Squiz.Commenting.FunctionComment.Missing
	public function run() {
		if ( $this->get_setting_value( 'disabled' ) ) {
			$this->disable_file_edit();
		}
	}

	/**
	 * Disable file editing
	 */
	public function disable_file_edit() {
		if ( ! defined( 'DISALLOW_FILE_EDIT' ) ) {
			// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedConstantFound
			define( 'DISALLOW_FILE_EDIT', true );
		}
	}
}
